@@ -7,16 +7,8 @@ from .. import BasicProvider, RedirectNeeded
 class DummyProvider(BasicProvider):
     '''
     Dummy payment provider
-
-    url:
-        return URL, user will be bounced to this address after payment is
-        processed
     '''
 
-    def __init__(self, *args, **kwargs):
-        self._url = kwargs.pop('url')
-        super(DummyProvider, self).__init__(*args, **kwargs)
-
     def get_form(self, data=None):
         form = DummyForm(data=data, hidden_inputs=False, provider=self,
                          payment=self.payment)
