@@ -33,7 +33,7 @@ class PaymentForm(BasePaymentForm):
                     description=u'%s %s' % (self.payment.billing_last_name,
                                             self.payment.billing_first_name)
                 )
-            except stripe.CardError, e:
+            except stripe.CardError as e:
                 # The card has been declined
                 self._errors['__all__'] = self.error_class([e.message])
                 self.payment.change_status('error')
